@@ -69,7 +69,7 @@ class LoggingTestBase(unittest.TestCase):
         while self._created:
             os.unlink(self._created.pop())
 
-        assert loghandler._reopenable_handlers == []
+        self.assertEqual(loghandler._reopenable_handlers, [])
         loghandler.closeFiles()
         loghandler._reopenable_handlers == []
 
@@ -188,6 +188,58 @@ class TestConfig(LoggingTestBase):
         logger.removeHandler(logfile)
         logfile.close()
 
+    def test_with_timed_rotating_logfile(self):
+        fn = self.mktemp()
+        logger = self.check_simple_logger("<eventlog>\n"
+                                          "  <logfile>\n"
+                                          "    path %s\n"
+                                          "    level debug\n"
+                                          "    when D\n"
+                                          "    old-files 11\n"
+                                          "  </logfile>\n"
+                                          "</eventlog>" % fn)
+        logfile = logger.handlers[0]
+        self.assertEqual(logfile.level, logging.DEBUG)
+        self.assertEqual(logfile.backupCount, 11)
+        self.assertEqual(logfile.interval, 86400)
+        self.assert_(isinstance(logfile, loghandler.TimedRotatingFileHandler))
+        logger.removeHandler(logfile)
+        logfile.close()
+
+    def test_with_timed_rotating_logfile(self):
+        fn = self.mktemp()
+        logger = self.check_simple_logger("<eventlog>\n"
+                                          "  <logfile>\n"
+                                          "    path %s\n"
+                                          "    level debug\n"
+                                          "    when D\n"
+                                          "    interval 3\n"
+                                          "    old-files 11\n"
+                                          "  </logfile>\n"
+                                          "</eventlog>" % fn)
+        logfile = logger.handlers[0]
+        self.assertEqual(logfile.level, logging.DEBUG)
+        self.assertEqual(logfile.backupCount, 11)
+        self.assertEqual(logfile.interval, 86400*3)
+        self.assert_(isinstance(logfile, loghandler.TimedRotatingFileHandler))
+        logger.removeHandler(logfile)
+        logfile.close()
+
+    def test_with_timed_rotating_logfile_and_size_should_fail(self):
+        fn = self.mktemp()
+        self.assertRaises(
+            ValueError,
+            self.check_simple_logger, "<eventlog>\n"
+                                          "  <logfile>\n"
+                                          "    path %s\n"
+                                          "    level debug\n"
+                                          "    max-size 5mb\n"
+                                          "    when D\n"
+                                          "    old-files 10\n"
+                                          "  </logfile>\n"
+                                          "</eventlog>" % fn)
+
+
     def check_standard_stream(self, name):
         old_stream = getattr(sys, name)
         conf = self.get_config("""
@@ -386,7 +438,7 @@ class TestReopeningLogfiles(TestReopeningLogfilesBase):
             }
         text = self._sampleconfig_template % d
         conf = self.get_config(text)
-        assert len(conf.loggers) == 2
+        self.assertEqual(len(conf.loggers), 2)
         # Build the loggers from the configuration, and write to them:
         conf.loggers[0]().info("message 1")
         conf.loggers[1]().info("message 2")
@@ -444,6 +496,12 @@ class TestReopeningRotatingLogfiles(TestReopeningLogfilesBase):
           max-size 1mb
           old-files 3
         </logfile>
+        <logfile>
+          path  %(path1)s
+          level info
+          when D
+          old-files 3
+        </logfile>
       </logger>
 
       <logger>
@@ -472,7 +530,7 @@ class TestReopeningRotatingLogfiles(TestReopeningLogfilesBase):
             }
         text = self._sampleconfig_template % d
         conf = self.get_config(text)
-        assert len(conf.loggers) == 2
+        self.assertEqual(len(conf.loggers), 2)
         # Build the loggers from the configuration, and write to them:
         conf.loggers[0]().info("message 1")
         conf.loggers[1]().info("message 2")
